/**
 * Copyright (c) 2009 Motorola.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Diego Sandin (Motorola) - Initial Version
 */
package org.eclipse.mtj.core.project.midp;

import org.eclipse.mtj.core.project.IMetaData;
import org.eclipse.mtj.internal.core.project.midp.LibletProperties;

/**
 * IMetaData implementation for storing MIDP related metadata.
 * 
 * @since 1.0
 * @noimplement This interface is not intended to be implemented by clients.
 */
public interface IMIDPMetaData extends IMetaData {

    /**
     * Set the name that must be used on the project's jad file after deployment
     * 
     * @param jadFileName the jad file name
     */
    public abstract void setJadFileName(String jadFileName);

    /**
     * Return the name that must be used on the project's jad file after
     * deployment as specified in the project's metadata file.
     * 
     * @return the deployable jad file name.
     */
    public abstract String getJadFileName();
    
    public LibletProperties[] getLibletProperties();
    
    public void setLibletProperties(LibletProperties[] libletProperties);
}
